Structs
- Metric
Descriptor - Metadata for each metric, including type, help text, and optional custom labels.
- Prometheus
Serializer - A custom serializer that flattens structs into Prometheus metrics.
Enums
- Metric
Type - Metric type (counter, gauge, histogram, summary, etc.)
- Prometheus
Error - Error type for Prometheus serialization.
Functions
- to_
prometheus_ text - Primary helper to convert a
T: Serializeinto a Prometheus text string. - write_
prometheus_ text - Primary helper to write a
T: Serializeinto a n output stream as Prometheus text. This is useful for writing directly to a file or network stream.